/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.layout.page.template.admin.web.internal.importer;

import com.liferay.layout.page.template.importer.PortletConfigurationImporter;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ReferenceCardinality;
import org.osgi.service.component.annotations.ReferencePolicy;

/**
 * @author Jürgen Kappler
 */
@Component(service = PortletConfigurationImporterTracker.class)
public class PortletConfigurationImporterTracker {

	public PortletConfigurationImporter getPortletConfigurationImporter(
		String portletName) {

		return _portletConfigurationImporters.get(portletName);
	}

	@Reference(
		cardinality = ReferenceCardinality.MULTIPLE,
		policy = ReferencePolicy.DYNAMIC
	)
	protected void setPortletConfigurationImporter(
		PortletConfigurationImporter portletConfigurationImporter) {

		_portletConfigurationImporters.put(
			portletConfigurationImporter.getPortletName(),
			portletConfigurationImporter);
	}

	protected void unsetPortletConfigurationImporter(
		PortletConfigurationImporter portletConfigurationImporter) {

		_portletConfigurationImporters.remove(portletConfigurationImporter);
	}

	private final Map<String, PortletConfigurationImporter>
		_portletConfigurationImporters = new ConcurrentHashMap<>();

}